==> huaweicloudsdkiotda-3.1.63-py2.py3-none-any.whl: huaweicloudsdkiotda/v5/model/batch_target_result.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchTargetResult:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'target': 'str',
        'status': 'str',
        'error_code': 'str',
        'error_msg': 'str'
    }

    attribute_map = {
        'target': 'target',
        'status': 'status',
        'error_code': 'error_code',
        'error_msg': 'error_msg'
    }

    def __init__(self, target=None, status=None, error_code=None, error_msg=None):
        """BatchTargetResult

        The model defined in huaweicloud sdk

        :param target: 执行批量任务的目标。
        :type target: str
        :param status: 目标的执行结果，为success或failure
        :type status: str
        :param error_code: 操作失败的错误码
        :type error_code: str
        :param error_msg: 操作失败的错误描述
        :type error_msg: str
        """
        
        

        self._target = None
        self._status = None
        self._error_code = None
        self._error_msg = None
        self.discriminator = None

        if target is not None:
            self.target = target
        if status is not None:
            self.status = status
        if error_code is not None:
            self.error_code = error_code
        if error_msg is not None:
            self.error_msg = error_msg

    @property
    def target(self):
        """Gets the target of this BatchTargetResult.

        执行批量任务的目标。

        :return: The target of this BatchTargetResult.
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        """Sets the target of this BatchTargetResult.

        执行批量任务的目标。

        :param target: The target of this BatchTargetResult.
        :type target: str
        """
        self._target = target

    @property
    def status(self):
        """Gets the status of this BatchTargetResult.

        目标的执行结果，为success或failure

        :return: The status of this BatchTargetResult.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this BatchTargetResult.

        目标的执行结果，为success或failure

        :param status: The status of this BatchTargetResult.
        :type status: str
        """
        self._status = status

    @property
    def error_code(self):
        """Gets the error_code of this BatchTargetResult.

        操作失败的错误码

        :return: The error_code of this BatchTargetResult.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """Sets the error_code of this BatchTargetResult.

        操作失败的错误码

        :param error_code: The error_code of this BatchTargetResult.
        :type error_code: str
        """
        self._error_code = error_code

    @property
    def error_msg(self):
        """Gets the error_msg of this BatchTargetResult.

        操作失败的错误描述

        :return: The error_msg of this BatchTargetResult.
        :rtype: str
        """
        return self._error_msg

    @error_msg.setter
    def error_msg(self, error_msg):
        """Sets the error_msg of this BatchTargetResult.

        操作失败的错误描述

        :param error_msg: The error_msg of this BatchTargetResult.
        :type error_msg: str
        """
        self._error_msg = error_msg

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchTargetResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkiotda-3.1.153-py2.py3-none-any.whl: huaweicloudsdkiotda/v5/model/batch_target_result.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchTargetResult:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'target': 'str',
        'status': 'str',
        'error_code': 'str',
        'error_msg': 'str'
    }

    attribute_map = {
        'target': 'target',
        'status': 'status',
        'error_code': 'error_code',
        'error_msg': 'error_msg'
    }

    def __init__(self, target=None, status=None, error_code=None, error_msg=None):
        r"""BatchTargetResult

        The model defined in huaweicloud sdk

        :param target: 执行批量任务的目标。
        :type target: str
        :param status: 目标的执行结果，为success或failure
        :type status: str
        :param error_code: 操作失败的错误码
        :type error_code: str
        :param error_msg: 操作失败的错误描述
        :type error_msg: str
        """
        
        

        self._target = None
        self._status = None
        self._error_code = None
        self._error_msg = None
        self.discriminator = None

        if target is not None:
            self.target = target
        if status is not None:
            self.status = status
        if error_code is not None:
            self.error_code = error_code
        if error_msg is not None:
            self.error_msg = error_msg

    @property
    def target(self):
        r"""Gets the target of this BatchTargetResult.

        执行批量任务的目标。

        :return: The target of this BatchTargetResult.
        :rtype: str
        """
        return self._target

    @target.setter
    def target(self, target):
        r"""Sets the target of this BatchTargetResult.

        执行批量任务的目标。

        :param target: The target of this BatchTargetResult.
        :type target: str
        """
        self._target = target

    @property
    def status(self):
        r"""Gets the status of this BatchTargetResult.

        目标的执行结果，为success或failure

        :return: The status of this BatchTargetResult.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        r"""Sets the status of this BatchTargetResult.

        目标的执行结果，为success或failure

        :param status: The status of this BatchTargetResult.
        :type status: str
        """
        self._status = status

    @property
    def error_code(self):
        r"""Gets the error_code of this BatchTargetResult.

        操作失败的错误码

        :return: The error_code of this BatchTargetResult.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        r"""Sets the error_code of this BatchTargetResult.

        操作失败的错误码

        :param error_code: The error_code of this BatchTargetResult.
        :type error_code: str
        """
        self._error_code = error_code

    @property
    def error_msg(self):
        r"""Gets the error_msg of this BatchTargetResult.

        操作失败的错误描述

        :return: The error_msg of this BatchTargetResult.
        :rtype: str
        """
        return self._error_msg

    @error_msg.setter
    def error_msg(self, error_msg):
        r"""Sets the error_msg of this BatchTargetResult.

        操作失败的错误描述

        :param error_msg: The error_msg of this BatchTargetResult.
        :type error_msg: str
        """
        self._error_msg = error_msg

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchTargetResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
